summaryrefslogtreecommitdiffstats
path: root/options/m_option.h
diff options
context:
space:
mode:
Diffstat (limited to 'options/m_option.h')
-rw-r--r--options/m_option.h6
1 files changed, 5 insertions, 1 deletions
diff --git a/options/m_option.h b/options/m_option.h
index f47dac294e..af082a893d 100644
--- a/options/m_option.h
+++ b/options/m_option.h
@@ -129,7 +129,7 @@ struct m_obj_desc {
const char *init_options;
// Don't list entry with "help"
bool hidden;
// Callback to print custom help if "help" is passed
void (*print_help)(struct mp_log *log);
// Callback that allows you to override the static default values. The
// pointer p points to the struct described by options/priv_size, with
@@ -159,6 +159,10 @@ struct m_obj_list {
bool disallow_positional_parameters;
// Each sub-item is backed by global options (for AOs and VOs).
bool use_global_options;
+ // Callback to print additional custom help if "vf=help" is passed
+ void (*print_help_list)(struct mp_log *log);
+ // Callback to print help for _unknown_ entries with "vf=entry=help"
+ void (*print_unknown_entry_help)(struct mp_log *log, const char *name);
};
// Find entry by name
@@ -129,7 +129,7 @@ struct m_obj_desc {
// Don't list entry with "help"
bool hidden;
- // Callback to print custom help if "help" is passed
+ // Callback to print custom help if "vf=entry=help" is passed
void (*print_help)(struct mp_log *log);
// Callback that allows you to override the static default values. The